privatecatalogpb

package
v0.10.8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 18, 2025 License: Apache-2.0 Imports: 12 Imported by: 1

Documentation

Index

Constants

const (
	PrivateCatalog_SearchCatalogs_FullMethodName = "/google.cloud.privatecatalog.v1beta1.PrivateCatalog/SearchCatalogs"
	PrivateCatalog_SearchProducts_FullMethodName = "/google.cloud.privatecatalog.v1beta1.PrivateCatalog/SearchProducts"
	PrivateCatalog_SearchVersions_FullMethodName = "/google.cloud.privatecatalog.v1beta1.PrivateCatalog/SearchVersions"
)

Variables

var (
	AssetReference_AssetValidationState_name = map[int32]string{
		0: "ASSET_VALIDATION_STATE_UNSPECIFIED",
		1: "PENDING",
		2: "VALID",
		3: "INVALID",
	}
	AssetReference_AssetValidationState_value = map[string]int32{
		"ASSET_VALIDATION_STATE_UNSPECIFIED": 0,
		"PENDING":                            1,
		"VALID":                              2,
		"INVALID":                            3,
	}
)

Enum value maps for AssetReference_AssetValidationState.

var File_google_cloud_privatecatalog_v1beta1_private_catalog_proto protoreflect.FileDescriptor
var PrivateCatalog_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "google.cloud.privatecatalog.v1beta1.PrivateCatalog",
	HandlerType: (*PrivateCatalogServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "SearchCatalogs",
			Handler:    _PrivateCatalog_SearchCatalogs_Handler,
		},
		{
			MethodName: "SearchProducts",
			Handler:    _PrivateCatalog_SearchProducts_Handler,
		},
		{
			MethodName: "SearchVersions",
			Handler:    _PrivateCatalog_SearchVersions_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "google/cloud/privatecatalog/v1beta1/private_catalog.proto",
}

PrivateCatalog_ServiceDesc is the grpc.ServiceDesc for PrivateCatalog service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterPrivateCatalogServer

func RegisterPrivateCatalogServer(s grpc.ServiceRegistrar, srv PrivateCatalogServer)

Types

type AssetReference

type AssetReference struct {

	// Output only. A unique identifier among asset references in a product.
	Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// Output only. The human-readable description of the referenced asset. Maximum 256
	// characters in length.
	Description string `protobuf:"bytes,2,opt,name=description,proto3" json:"description,omitempty"`
	// Output only. The definition of input parameters to hydrate the asset template.
	Inputs *Inputs `protobuf:"bytes,6,opt,name=inputs,proto3" json:"inputs,omitempty"`
	// Output only. The current state of the asset reference.
	ValidationStatus AssetReference_AssetValidationState `` /* 187-byte string literal not displayed */
	// Output only. The validation process metadata.
	ValidationOperation *longrunningpb.Operation `protobuf:"bytes,8,opt,name=validation_operation,json=validationOperation,proto3" json:"validation_operation,omitempty"`
	// The destination of the asset.
	//
	// Types that are assignable to Source:
	//
	//	*AssetReference_Asset
	//	*AssetReference_GcsPath
	//	*AssetReference_GitSource
	Source isAssetReference_Source `protobuf_oneof:"source"`
	// Output only. The cloud storage source.
	GcsSource *GcsSource `protobuf:"bytes,16,opt,name=gcs_source,json=gcsSource,proto3" json:"gcs_source,omitempty"`
	// Output only. The creation timestamp of the asset reference.
	CreateTime *timestamppb.Timestamp `protobuf:"bytes,12,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
	// Output only. The last update timestamp of the asset reference.
	UpdateTime *timestamppb.Timestamp `protobuf:"bytes,13,opt,name=update_time,json=updateTime,proto3" json:"update_time,omitempty"`
	// The version of the source used for this asset reference.
	//
	// Deprecated: Marked as deprecated in google/cloud/privatecatalog/v1beta1/private_catalog.proto.
	Version string `protobuf:"bytes,14,opt,name=version,proto3" json:"version,omitempty"`
	// contains filtered or unexported fields
}

Defines the reference of an asset belonging to a product.

func (*AssetReference) Descriptor deprecated

func (*AssetReference) Descriptor() ([]byte, []int)

Deprecated: Use AssetReference.ProtoReflect.Descriptor instead.

func (*AssetReference) GetAsset

func (x *AssetReference) GetAsset() string

func (*AssetReference) GetCreateTime

func (x *AssetReference) GetCreateTime() *timestamppb.Timestamp

func (*AssetReference) GetDescription

func (x *AssetReference) GetDescription() string

func (*AssetReference) GetGcsPath deprecated

func (x *AssetReference) GetGcsPath() string

Deprecated: Marked as deprecated in google/cloud/privatecatalog/v1beta1/private_catalog.proto.

func (*AssetReference) GetGcsSource

func (x *AssetReference) GetGcsSource() *GcsSource

func (*AssetReference) GetGitSource

func (x *AssetReference) GetGitSource() *GitSource

func (*AssetReference) GetId

func (x *AssetReference) GetId() string

func (*AssetReference) GetInputs

func (x *AssetReference) GetInputs() *Inputs

func (*AssetReference) GetSource

func (m *AssetReference) GetSource() isAssetReference_Source

func (*AssetReference) GetUpdateTime

func (x *AssetReference) GetUpdateTime() *timestamppb.Timestamp

func (*AssetReference) GetValidationOperation

func (x *AssetReference) GetValidationOperation() *longrunningpb.Operation

func (*AssetReference) GetValidationStatus

func (x *AssetReference) GetValidationStatus() AssetReference_AssetValidationState

func (*AssetReference) GetVersion deprecated

func (x *AssetReference) GetVersion() string

Deprecated: Marked as deprecated in google/cloud/privatecatalog/v1beta1/private_catalog.proto.

func (*AssetReference) ProtoMessage

func (*AssetReference) ProtoMessage()

func (*AssetReference) ProtoReflect

func (x *AssetReference) ProtoReflect() protoreflect.Message

func (*AssetReference) Reset

func (x *AssetReference) Reset()

func (*AssetReference) String

func (x *AssetReference) String() string

type AssetReference_Asset

type AssetReference_Asset struct {
	// Output only. The asset resource name if an asset is hosted by Private Catalog.
	Asset string `protobuf:"bytes,10,opt,name=asset,proto3,oneof"`
}

type AssetReference_AssetValidationState

type AssetReference_AssetValidationState int32

Possible validation steates of an asset reference.

const (
	// Unknown state.
	AssetReference_ASSET_VALIDATION_STATE_UNSPECIFIED AssetReference_AssetValidationState = 0
	// The validation is still in process.
	AssetReference_PENDING AssetReference_AssetValidationState = 1
	// The validation is done and the asset reference is valid.
	AssetReference_VALID AssetReference_AssetValidationState = 2
	// The validation is done and the asset reference is invalid.
	AssetReference_INVALID AssetReference_AssetValidationState = 3
)

func (AssetReference_AssetValidationState) Descriptor

func (AssetReference_AssetValidationState) Enum

func (AssetReference_AssetValidationState) EnumDescriptor deprecated

func (AssetReference_AssetValidationState) EnumDescriptor() ([]byte, []int)

Deprecated: Use AssetReference_AssetValidationState.Descriptor instead.

func (AssetReference_AssetValidationState) Number

func (AssetReference_AssetValidationState) String

func (AssetReference_AssetValidationState) Type

type AssetReference_GcsPath

type AssetReference_GcsPath struct {
	// Output only. The cloud storage object path.
	//
	// Deprecated: Marked as deprecated in google/cloud/privatecatalog/v1beta1/private_catalog.proto.
	GcsPath string `protobuf:"bytes,11,opt,name=gcs_path,json=gcsPath,proto3,oneof"`
}

type AssetReference_GitSource

type AssetReference_GitSource struct {
	// Output only. The git source.
	GitSource *GitSource `protobuf:"bytes,15,opt,name=git_source,json=gitSource,proto3,oneof"`
}

type Catalog

type Catalog struct {

	// Output only. The resource name of the target catalog, in the format of
	// `catalogs/{catalog}`.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Output only. The descriptive name of the catalog as it appears in UIs.
	DisplayName string `protobuf:"bytes,2,opt,name=display_name,json=displayName,proto3" json:"display_name,omitempty"`
	// Output only. The description of the catalog.
	Description string `protobuf:"bytes,3,opt,name=description,proto3" json:"description,omitempty"`
	// Output only. The time when the catalog was created.
	CreateTime *timestamppb.Timestamp `protobuf:"bytes,4,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
	// Output only. The time when the catalog was last updated.
	UpdateTime *timestamppb.Timestamp `protobuf:"bytes,5,opt,name=update_time,json=updateTime,proto3" json:"update_time,omitempty"`
	// contains filtered or unexported fields
}

The readonly representation of a catalog computed with a given resource context.

func (*Catalog) Descriptor deprecated

func (*Catalog) Descriptor() ([]byte, []int)

Deprecated: Use Catalog.ProtoReflect.Descriptor instead.

func (*Catalog) GetCreateTime

func (x *Catalog) GetCreateTime() *timestamppb.Timestamp

func (*Catalog) GetDescription

func (x *Catalog) GetDescription() string

func (*Catalog) GetDisplayName

func (x *Catalog) GetDisplayName() string

func (*Catalog) GetName

func (x *Catalog) GetName() string

func (*Catalog) GetUpdateTime

func (x *Catalog) GetUpdateTime() *timestamppb.Timestamp

func (*Catalog) ProtoMessage

func (*Catalog) ProtoMessage()

func (*Catalog) ProtoReflect

func (x *Catalog) ProtoReflect() protoreflect.Message

func (*Catalog) Reset

func (x *Catalog) Reset()

func (*Catalog) String

func (x *Catalog) String() string

type GcsSource

type GcsSource struct {

	// Output only. the cloud storage object path.
	GcsPath string `protobuf:"bytes,1,opt,name=gcs_path,json=gcsPath,proto3" json:"gcs_path,omitempty"`
	// Output only. Generation of the object, which is set when the content of an object starts
	// being written.
	Generation int64 `protobuf:"varint,2,opt,name=generation,proto3" json:"generation,omitempty"`
	// Output only. The time when the object metadata was last changed.
	UpdateTime *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=update_time,json=updateTime,proto3" json:"update_time,omitempty"`
	// contains filtered or unexported fields
}

Defines how to access Cloud Storage source.

func (*GcsSource) Descriptor deprecated

func (*GcsSource) Descriptor() ([]byte, []int)

Deprecated: Use GcsSource.ProtoReflect.Descriptor instead.

func (*GcsSource) GetGcsPath

func (x *GcsSource) GetGcsPath() string

func (*GcsSource) GetGeneration

func (x *GcsSource) GetGeneration() int64

func (*GcsSource) GetUpdateTime

func (x *GcsSource) GetUpdateTime() *timestamppb.Timestamp

func (*GcsSource) ProtoMessage

func (*GcsSource) ProtoMessage()

func (*GcsSource) ProtoReflect

func (x *GcsSource) ProtoReflect() protoreflect.Message

func (*GcsSource) Reset

func (x *GcsSource) Reset()

func (*GcsSource) String

func (x *GcsSource) String() string

type GitSource

type GitSource struct {

	// Location of the Git repo to build.
	Repo string `protobuf:"bytes,1,opt,name=repo,proto3" json:"repo,omitempty"`
	// Directory, relative to the source root, in which to run the build.
	//
	// This must be a relative path. If a step's `dir` is specified and is an
	// absolute path, this value is ignored for that step's execution.
	Dir string `protobuf:"bytes,2,opt,name=dir,proto3" json:"dir,omitempty"`
	// The revision to fetch from the Git repository such as a branch, a tag, a
	// commit SHA, or any Git ref.
	//
	// Types that are assignable to Ref:
	//
	//	*GitSource_Commit
	//	*GitSource_Branch
	//	*GitSource_Tag
	Ref isGitSource_Ref `protobuf_oneof:"ref"`
	// contains filtered or unexported fields
}

Defines how to access a Git Source.

func (*GitSource) Descriptor deprecated

func (*GitSource) Descriptor() ([]byte, []int)

Deprecated: Use GitSource.ProtoReflect.Descriptor instead.

func (*GitSource) GetBranch

func (x *GitSource) GetBranch() string

func (*GitSource) GetCommit

func (x *GitSource) GetCommit() string

func (*GitSource) GetDir

func (x *GitSource) GetDir() string

func (*GitSource) GetRef

func (m *GitSource) GetRef() isGitSource_Ref

func (*GitSource) GetRepo

func (x *GitSource) GetRepo() string

func (*GitSource) GetTag

func (x *GitSource) GetTag() string

func (*GitSource) ProtoMessage

func (*GitSource) ProtoMessage()

func (*GitSource) ProtoReflect

func (x *GitSource) ProtoReflect() protoreflect.Message

func (*GitSource) Reset

func (x *GitSource) Reset()

func (*GitSource) String

func (x *GitSource) String() string

type GitSource_Branch

type GitSource_Branch struct {
	// The revision branch to use.
	Branch string `protobuf:"bytes,4,opt,name=branch,proto3,oneof"`
}

type GitSource_Commit

type GitSource_Commit struct {
	// The revision commit to use.
	Commit string `protobuf:"bytes,3,opt,name=commit,proto3,oneof"`
}

type GitSource_Tag

type GitSource_Tag struct {
	// The revision tag to use.
	Tag string `protobuf:"bytes,5,opt,name=tag,proto3,oneof"`
}

type Inputs

type Inputs struct {

	// Output only. The JSON schema defining the inputs and their formats.
	Parameters *structpb.Struct `protobuf:"bytes,1,opt,name=parameters,proto3" json:"parameters,omitempty"`
	// contains filtered or unexported fields
}

Defines definition of input parameters of asset templates.

func (*Inputs) Descriptor deprecated

func (*Inputs) Descriptor() ([]byte, []int)

Deprecated: Use Inputs.ProtoReflect.Descriptor instead.

func (*Inputs) GetParameters

func (x *Inputs) GetParameters() *structpb.Struct

func (*Inputs) ProtoMessage

func (*Inputs) ProtoMessage()

func (*Inputs) ProtoReflect

func (x *Inputs) ProtoReflect() protoreflect.Message

func (*Inputs) Reset

func (x *Inputs) Reset()

func (*Inputs) String

func (x *Inputs) String() string

type PrivateCatalogClient

type PrivateCatalogClient interface {
	// Search [Catalog][google.cloud.privatecatalog.v1beta1.Catalog] resources that consumers have access to, within the
	// scope of the consumer cloud resource hierarchy context.
	SearchCatalogs(ctx context.Context, in *SearchCatalogsRequest, opts ...grpc.CallOption) (*SearchCatalogsResponse, error)
	// Search [Product][google.cloud.privatecatalog.v1beta1.Product] resources that consumers have access to, within the
	// scope of the consumer cloud resource hierarchy context.
	SearchProducts(ctx context.Context, in *SearchProductsRequest, opts ...grpc.CallOption) (*SearchProductsResponse, error)
	// Search [Version][google.cloud.privatecatalog.v1beta1.Version] resources that consumers have access to, within the
	// scope of the consumer cloud resource hierarchy context.
	SearchVersions(ctx context.Context, in *SearchVersionsRequest, opts ...grpc.CallOption) (*SearchVersionsResponse, error)
}

PrivateCatalogClient is the client API for PrivateCatalog service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type PrivateCatalogServer

type PrivateCatalogServer interface {
	// Search [Catalog][google.cloud.privatecatalog.v1beta1.Catalog] resources that consumers have access to, within the
	// scope of the consumer cloud resource hierarchy context.
	SearchCatalogs(context.Context, *SearchCatalogsRequest) (*SearchCatalogsResponse, error)
	// Search [Product][google.cloud.privatecatalog.v1beta1.Product] resources that consumers have access to, within the
	// scope of the consumer cloud resource hierarchy context.
	SearchProducts(context.Context, *SearchProductsRequest) (*SearchProductsResponse, error)
	// Search [Version][google.cloud.privatecatalog.v1beta1.Version] resources that consumers have access to, within the
	// scope of the consumer cloud resource hierarchy context.
	SearchVersions(context.Context, *SearchVersionsRequest) (*SearchVersionsResponse, error)
}

PrivateCatalogServer is the server API for PrivateCatalog service. All implementations should embed UnimplementedPrivateCatalogServer for forward compatibility

type Product

type Product struct {

	// Output only. The resource name of the target product, in the format of
	// `products/[a-z][-a-z0-9]*[a-z0-9]'.
	//
	// A unique identifier for the product under a catalog.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Output only. The type of the product asset. It can be one of the following values:
	//
	// * `google.deploymentmanager.Template`
	// * `google.cloudprivatecatalog.ListingOnly`
	// * `google.cloudprivatecatalog.Terraform`
	AssetType string `protobuf:"bytes,2,opt,name=asset_type,json=assetType,proto3" json:"asset_type,omitempty"`
	// Required. Output only. The display metadata to describe the product. The JSON schema of the
	// metadata differs by [Product.asset_type][google.cloud.privatecatalog.v1beta1.Product.asset_type].
	// When the type is `google.deploymentmanager.Template`, the schema is as
	// follows:
	//
	// “`
	// "$schema": http://json-schema.org/draft-04/schema#
	// type: object
	// properties:
	//
	//	name:
	//	  type: string
	//	  minLength: 1
	//	  maxLength: 64
	//	description:
	//	  type: string
	//	  minLength: 1
	//	  maxLength: 2048
	//	tagline:
	//	  type: string
	//	  minLength: 1
	//	  maxLength: 100
	//	support_info:
	//	  type: string
	//	  minLength: 1
	//	  maxLength: 2048
	//	creator:
	//	  type: string
	//	  minLength: 1
	//	  maxLength: 100
	//	documentations:
	//	  type: array
	//	  items:
	//	    type: object
	//	    properties:
	//	      url:
	//	        type: string
	//	        pattern:
	//	        "^(https?)://[-a-zA-Z0-9+&@#/%?=~_|!:,.;]*[-a-zA-Z0-9+&@#/%=~_|]"
	//	      title:
	//	        type: string
	//	        minLength: 1
	//	        maxLength: 64
	//	      description:
	//	        type: string
	//	        minLength: 1
	//	        maxLength: 2048
	//
	// required:
	// - name
	// - description
	// additionalProperties: false
	//
	// “`
	//
	// When the asset type is `google.cloudprivatecatalog.ListingOnly`, the schema
	// is as follows:
	//
	// “`
	// "$schema": http://json-schema.org/draft-04/schema#
	// type: object
	// properties:
	//
	//	name:
	//	  type: string
	//	  minLength: 1
	//	  maxLength: 64
	//	description:
	//	  type: string
	//	  minLength: 1
	//	  maxLength: 2048
	//	tagline:
	//	  type: string
	//	  minLength: 1
	//	  maxLength: 100
	//	support_info:
	//	  type: string
	//	  minLength: 1
	//	  maxLength: 2048
	//	creator:
	//	  type: string
	//	  minLength: 1
	//	  maxLength: 100
	//	documentations:
	//	  type: array
	//	  items:
	//	    type: object
	//	    properties:
	//	      url:
	//	        type: string
	//	        pattern:
	//	        "^(https?)://[-a-zA-Z0-9+&@#/%?=~_|!:,.;]*[-a-zA-Z0-9+&@#/%=~_|]"
	//	      title:
	//	        type: string
	//	        minLength: 1
	//	        maxLength: 64
	//	      description:
	//	        type: string
	//	        minLength: 1
	//	        maxLength: 2048
	//	signup_url:
	//	  type: string
	//	  pattern:
	//	  "^(https?)://[-a-zA-Z0-9+&@#/%?=~_|!:,.;]*[-a-zA-Z0-9+&@#/%=~_|]"
	//
	// required:
	// - name
	// - description
	// - signup_url
	// additionalProperties: false
	//
	// “`
	//
	// When the asset type is `google.cloudprivatecatalog.Terraform`, the schema
	// is as follows:
	//
	// “`
	// "$schema": http://json-schema.org/draft-04/schema#
	// type: object
	// properties:
	//
	//	name:
	//	  type: string
	//	  minLength: 1
	//	  maxLength: 64
	//	description:
	//	  type: string
	//	  minLength: 1
	//	  maxLength: 2048
	//	tagline:
	//	  type: string
	//	  minLength: 1
	//	  maxLength: 100
	//	support_info:
	//	  type: string
	//	  minLength: 1
	//	  maxLength: 2048
	//	creator:
	//	  type: string
	//	  minLength: 1
	//	  maxLength: 100
	//	documentations:
	//	  type: array
	//	  items:
	//	    type: object
	//	    properties:
	//	      url:
	//	        type: string
	//	        pattern:
	//	        "^(https?)://[-a-zA-Z0-9+&@#/%?=~_|!:,.;]*[-a-zA-Z0-9+&@#/%=~_|]"
	//	      title:
	//	        type: string
	//	        minLength: 1
	//	        maxLength: 64
	//	      description:
	//	        type: string
	//	        minLength: 1
	//	        maxLength: 2048
	//
	// required:
	// - name
	// - description
	// additionalProperties: true
	DisplayMetadata *structpb.Struct `protobuf:"bytes,3,opt,name=display_metadata,json=displayMetadata,proto3" json:"display_metadata,omitempty"`
	// Output only. The icon URI of the product.
	IconUri string `protobuf:"bytes,4,opt,name=icon_uri,json=iconUri,proto3" json:"icon_uri,omitempty"`
	// Output only. A collection of assets referred by a product.
	// This field is set for Terraform Products only.
	AssetReferences []*AssetReference `protobuf:"bytes,10,rep,name=asset_references,json=assetReferences,proto3" json:"asset_references,omitempty"`
	// Output only. The time when the product was created.
	CreateTime *timestamppb.Timestamp `protobuf:"bytes,5,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
	// Output only. The time when the product was last updated.
	UpdateTime *timestamppb.Timestamp `protobuf:"bytes,6,opt,name=update_time,json=updateTime,proto3" json:"update_time,omitempty"`
	// contains filtered or unexported fields
}

The readonly representation of a product computed with a given resource context.

func (*Product) Descriptor deprecated

func (*Product) Descriptor() ([]byte, []int)

Deprecated: Use Product.ProtoReflect.Descriptor instead.

func (*Product) GetAssetReferences

func (x *Product) GetAssetReferences() []*AssetReference

func (*Product) GetAssetType

func (x *Product) GetAssetType() string

func (*Product) GetCreateTime

func (x *Product) GetCreateTime() *timestamppb.Timestamp

func (*Product) GetDisplayMetadata

func (x *Product) GetDisplayMetadata() *structpb.Struct

func (*Product) GetIconUri

func (x *Product) GetIconUri() string

func (*Product) GetName

func (x *Product) GetName() string

func (*Product) GetUpdateTime

func (x *Product) GetUpdateTime() *timestamppb.Timestamp

func (*Product) ProtoMessage

func (*Product) ProtoMessage()

func (*Product) ProtoReflect

func (x *Product) ProtoReflect() protoreflect.Message

func (*Product) Reset

func (x *Product) Reset()

func (*Product) String

func (x *Product) String() string

type SearchCatalogsRequest

type SearchCatalogsRequest struct {

	// Required. The name of the resource context. It can be in following formats:
	//
	// * `projects/{project}`
	// * `folders/{folder}`
	// * `organizations/{organization}`
	Resource string `protobuf:"bytes,1,opt,name=resource,proto3" json:"resource,omitempty"`
	// The query to filter the catalogs. The supported queries are:
	//
	// * Get a single catalog: `name=catalogs/{catalog}`
	Query string `protobuf:"bytes,2,opt,name=query,proto3" json:"query,omitempty"`
	// The maximum number of entries that are requested.
	PageSize int32 `protobuf:"varint,3,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
	// A pagination token returned from a previous call to SearchCatalogs that
	// indicates where this listing should continue from.
	PageToken string `protobuf:"bytes,4,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
	// contains filtered or unexported fields
}

Request message for [PrivateCatalog.SearchCatalogs][google.cloud.privatecatalog.v1beta1.PrivateCatalog.SearchCatalogs].

func (*SearchCatalogsRequest) Descriptor deprecated

func (*SearchCatalogsRequest) Descriptor() ([]byte, []int)

Deprecated: Use SearchCatalogsRequest.ProtoReflect.Descriptor instead.

func (*SearchCatalogsRequest) GetPageSize

func (x *SearchCatalogsRequest) GetPageSize() int32

func (*SearchCatalogsRequest) GetPageToken

func (x *SearchCatalogsRequest) GetPageToken() string

func (*SearchCatalogsRequest) GetQuery

func (x *SearchCatalogsRequest) GetQuery() string

func (*SearchCatalogsRequest) GetResource

func (x *SearchCatalogsRequest) GetResource() string

func (*SearchCatalogsRequest) ProtoMessage

func (*SearchCatalogsRequest) ProtoMessage()

func (*SearchCatalogsRequest) ProtoReflect

func (x *SearchCatalogsRequest) ProtoReflect() protoreflect.Message

func (*SearchCatalogsRequest) Reset

func (x *SearchCatalogsRequest) Reset()

func (*SearchCatalogsRequest) String

func (x *SearchCatalogsRequest) String() string

type SearchCatalogsResponse

type SearchCatalogsResponse struct {

	// The `Catalog`s computed from the resource context.
	Catalogs []*Catalog `protobuf:"bytes,1,rep,name=catalogs,proto3" json:"catalogs,omitempty"`
	// A pagination token returned from a previous call to SearchCatalogs that
	// indicates from where listing should continue.
	NextPageToken string `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
	// contains filtered or unexported fields
}

Response message for [PrivateCatalog.SearchCatalogs][google.cloud.privatecatalog.v1beta1.PrivateCatalog.SearchCatalogs].

func (*SearchCatalogsResponse) Descriptor deprecated

func (*SearchCatalogsResponse) Descriptor() ([]byte, []int)

Deprecated: Use SearchCatalogsResponse.ProtoReflect.Descriptor instead.

func (*SearchCatalogsResponse) GetCatalogs

func (x *SearchCatalogsResponse) GetCatalogs() []*Catalog

func (*SearchCatalogsResponse) GetNextPageToken

func (x *SearchCatalogsResponse) GetNextPageToken() string

func (*SearchCatalogsResponse) ProtoMessage

func (*SearchCatalogsResponse) ProtoMessage()

func (*SearchCatalogsResponse) ProtoReflect

func (x *SearchCatalogsResponse) ProtoReflect() protoreflect.Message

func (*SearchCatalogsResponse) Reset

func (x *SearchCatalogsResponse) Reset()

func (*SearchCatalogsResponse) String

func (x *SearchCatalogsResponse) String() string

type SearchProductsRequest

type SearchProductsRequest struct {

	// Required. The name of the resource context. See [SearchCatalogsRequest.resource][google.cloud.privatecatalog.v1beta1.SearchCatalogsRequest.resource]
	// for details.
	Resource string `protobuf:"bytes,1,opt,name=resource,proto3" json:"resource,omitempty"`
	// The query to filter the products.
	//
	// The supported queries are:
	// * List products of all catalogs: empty
	// * List products under a catalog: `parent=catalogs/{catalog}`
	// * Get a product by name:
	// `name=catalogs/{catalog}/products/{product}`
	Query string `protobuf:"bytes,2,opt,name=query,proto3" json:"query,omitempty"`
	// The maximum number of entries that are requested.
	PageSize int32 `protobuf:"varint,3,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
	// A pagination token returned from a previous call to SearchProducts that
	// indicates where this listing should continue from.
	PageToken string `protobuf:"bytes,4,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
	// contains filtered or unexported fields
}

Request message for [PrivateCatalog.SearchProducts][google.cloud.privatecatalog.v1beta1.PrivateCatalog.SearchProducts].

func (*SearchProductsRequest) Descriptor deprecated

func (*SearchProductsRequest) Descriptor() ([]byte, []int)

Deprecated: Use SearchProductsRequest.ProtoReflect.Descriptor instead.

func (*SearchProductsRequest) GetPageSize

func (x *SearchProductsRequest) GetPageSize() int32

func (*SearchProductsRequest) GetPageToken

func (x *SearchProductsRequest) GetPageToken() string

func (*SearchProductsRequest) GetQuery

func (x *SearchProductsRequest) GetQuery() string

func (*SearchProductsRequest) GetResource

func (x *SearchProductsRequest) GetResource() string

func (*SearchProductsRequest) ProtoMessage

func (*SearchProductsRequest) ProtoMessage()

func (*SearchProductsRequest) ProtoReflect

func (x *SearchProductsRequest) ProtoReflect() protoreflect.Message

func (*SearchProductsRequest) Reset

func (x *SearchProductsRequest) Reset()

func (*SearchProductsRequest) String

func (x *SearchProductsRequest) String() string

type SearchProductsResponse

type SearchProductsResponse struct {

	// The `Product` resources computed from the resource context.
	Products []*Product `protobuf:"bytes,1,rep,name=products,proto3" json:"products,omitempty"`
	// A pagination token returned from a previous call to SearchProducts that
	// indicates from where listing should continue.
	NextPageToken string `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
	// contains filtered or unexported fields
}

Response message for [PrivateCatalog.SearchProducts][google.cloud.privatecatalog.v1beta1.PrivateCatalog.SearchProducts].

func (*SearchProductsResponse) Descriptor deprecated

func (*SearchProductsResponse) Descriptor() ([]byte, []int)

Deprecated: Use SearchProductsResponse.ProtoReflect.Descriptor instead.

func (*SearchProductsResponse) GetNextPageToken

func (x *SearchProductsResponse) GetNextPageToken() string

func (*SearchProductsResponse) GetProducts

func (x *SearchProductsResponse) GetProducts() []*Product

func (*SearchProductsResponse) ProtoMessage

func (*SearchProductsResponse) ProtoMessage()

func (*SearchProductsResponse) ProtoReflect

func (x *SearchProductsResponse) ProtoReflect() protoreflect.Message

func (*SearchProductsResponse) Reset

func (x *SearchProductsResponse) Reset()

func (*SearchProductsResponse) String

func (x *SearchProductsResponse) String() string

type SearchVersionsRequest

type SearchVersionsRequest struct {

	// Required. The name of the resource context. See [SearchCatalogsRequest.resource][google.cloud.privatecatalog.v1beta1.SearchCatalogsRequest.resource]
	// for details.
	Resource string `protobuf:"bytes,1,opt,name=resource,proto3" json:"resource,omitempty"`
	// Required. The query to filter the versions.
	//
	// The supported queries are:
	// * List versions under a product:
	// `parent=catalogs/{catalog}/products/{product}`
	// * Get a version by name:
	// `name=catalogs/{catalog}/products/{product}/versions/{version}`
	Query string `protobuf:"bytes,2,opt,name=query,proto3" json:"query,omitempty"`
	// The maximum number of entries that are requested.
	PageSize int32 `protobuf:"varint,3,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
	// A pagination token returned from a previous call to SearchVersions
	// that indicates where this listing should continue from.
	PageToken string `protobuf:"bytes,4,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
	// contains filtered or unexported fields
}

Request message for [PrivateCatalog.SearchVersions][google.cloud.privatecatalog.v1beta1.PrivateCatalog.SearchVersions].

func (*SearchVersionsRequest) Descriptor deprecated

func (*SearchVersionsRequest) Descriptor() ([]byte, []int)

Deprecated: Use SearchVersionsRequest.ProtoReflect.Descriptor instead.

func (*SearchVersionsRequest) GetPageSize

func (x *SearchVersionsRequest) GetPageSize() int32

func (*SearchVersionsRequest) GetPageToken

func (x *SearchVersionsRequest) GetPageToken() string

func (*SearchVersionsRequest) GetQuery

func (x *SearchVersionsRequest) GetQuery() string

func (*SearchVersionsRequest) GetResource

func (x *SearchVersionsRequest) GetResource() string

func (*SearchVersionsRequest) ProtoMessage

func (*SearchVersionsRequest) ProtoMessage()

func (*SearchVersionsRequest) ProtoReflect

func (x *SearchVersionsRequest) ProtoReflect() protoreflect.Message

func (*SearchVersionsRequest) Reset

func (x *SearchVersionsRequest) Reset()

func (*SearchVersionsRequest) String

func (x *SearchVersionsRequest) String() string

type SearchVersionsResponse

type SearchVersionsResponse struct {

	// The `Version` resources computed from the resource context.
	Versions []*Version `protobuf:"bytes,1,rep,name=versions,proto3" json:"versions,omitempty"`
	// A pagination token returned from a previous call to SearchVersions that
	// indicates from where the listing should continue.
	NextPageToken string `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
	// contains filtered or unexported fields
}

Response message for [PrivateCatalog.SearchVersions][google.cloud.privatecatalog.v1beta1.PrivateCatalog.SearchVersions].

func (*SearchVersionsResponse) Descriptor deprecated

func (*SearchVersionsResponse) Descriptor() ([]byte, []int)

Deprecated: Use SearchVersionsResponse.ProtoReflect.Descriptor instead.

func (*SearchVersionsResponse) GetNextPageToken

func (x *SearchVersionsResponse) GetNextPageToken() string

func (*SearchVersionsResponse) GetVersions

func (x *SearchVersionsResponse) GetVersions() []*Version

func (*SearchVersionsResponse) ProtoMessage

func (*SearchVersionsResponse) ProtoMessage()

func (*SearchVersionsResponse) ProtoReflect

func (x *SearchVersionsResponse) ProtoReflect() protoreflect.Message

func (*SearchVersionsResponse) Reset

func (x *SearchVersionsResponse) Reset()

func (*SearchVersionsResponse) String

func (x *SearchVersionsResponse) String() string

type UnimplementedPrivateCatalogServer

type UnimplementedPrivateCatalogServer struct {
}

UnimplementedPrivateCatalogServer should be embedded to have forward compatible implementations.

func (UnimplementedPrivateCatalogServer) SearchCatalogs

func (UnimplementedPrivateCatalogServer) SearchProducts

func (UnimplementedPrivateCatalogServer) SearchVersions

type UnsafePrivateCatalogServer added in v0.10.8

type UnsafePrivateCatalogServer interface {
	// contains filtered or unexported methods
}

UnsafePrivateCatalogServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to PrivateCatalogServer will result in compilation errors.

type Version

type Version struct {

	// Output only. The resource name of the version, in the format
	// `catalogs/{catalog}/products/{product}/versions/[a-z][-a-z0-9]*[a-z0-9]`.
	//
	// A unique identifier for the version under a product.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Output only. The user-supplied description of the version. Maximum of 256
	// characters.
	Description string `protobuf:"bytes,2,opt,name=description,proto3" json:"description,omitempty"`
	// Output only. The asset which has been validated and is ready to be
	// provisioned. See
	// [google.cloud.privatecatalogproducer.v1beta.Version.asset][] for details.
	Asset *structpb.Struct `protobuf:"bytes,3,opt,name=asset,proto3" json:"asset,omitempty"`
	// Output only. The time when the version was created.
	CreateTime *timestamppb.Timestamp `protobuf:"bytes,5,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
	// Output only. The time when the version was last updated.
	UpdateTime *timestamppb.Timestamp `protobuf:"bytes,6,opt,name=update_time,json=updateTime,proto3" json:"update_time,omitempty"`
	// contains filtered or unexported fields
}

The consumer representation of a version which is a child resource under a `Product` with asset data.

func (*Version) Descriptor deprecated

func (*Version) Descriptor() ([]byte, []int)

Deprecated: Use Version.ProtoReflect.Descriptor instead.

func (*Version) GetAsset

func (x *Version) GetAsset() *structpb.Struct

func (*Version) GetCreateTime

func (x *Version) GetCreateTime() *timestamppb.Timestamp

func (*Version) GetDescription

func (x *Version) GetDescription() string

func (*Version) GetName

func (x *Version) GetName() string

func (*Version) GetUpdateTime

func (x *Version) GetUpdateTime() *timestamppb.Timestamp

func (*Version) ProtoMessage

func (*Version) ProtoMessage()

func (*Version) ProtoReflect

func (x *Version) ProtoReflect() protoreflect.Message

func (*Version) Reset

func (x *Version) Reset()

func (*Version) String

func (x *Version) String() string

Jump to